@@ -64,9 +64,12 @@ Get the entry's timestamp (retention time)
 
 Get the text message
 
-
 =back
 
+=head1 SEE ALSO
+
+L<uf-error>
+
 =head1 AUTHOR
 
 Gene Selkov, E<lt>selkovjr@gmail.comE<gt>
